WebAuthenticationOptions class

Constructors

WebAuthenticationOptions({required String clientId, required Uri redirectUri})
const

Properties

clientId → String
The developer’s client identifier, as provided by WWDR.
final
hashCode → int
The hash code for this object.
no setterinherited
redirectUri → Uri
The URI to which the authorization redirects. It must include a domain name, and can’t be an IP address or localhost.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited